@@ -2,37 +2,29 @@
 #ifndef _GLIBMM_CONTAINERS_H
 #define _GLIBMM_CONTAINERS_H
 
-/* $Id: containers.h 229 2005-11-23 07:22:43Z murrayc $ */
-
 /* containers.h
  *
  * Copyright (C) 1998-2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/glist.h>
-#include <glib/gslist.h>
-#include <glibmm/sarray.h> /* for backward compatibility */
-
-#include <iterator>
 #include <glibmmconfig.h>
-
-GLIBMM_USING_STD(bidirectional_iterator_tag)
-GLIBMM_USING_STD(forward_iterator_tag)
-
+#include <glibmm/sarray.h> /* for backward compatibility */
+#include <glib.h>
+#include <iterator>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
@@ -125,12 +117,12 @@ public:
     return tmp;
   }
 
-  reference operator*()  const 
+  reference operator*() const
   {
     return *(pointer)( node_ ? node_->data : glibmm_null_pointer );
   }
-  
-  pointer operator -> () const { return &operator*(); }
+
+  pointer operator->() const { return &**this; }
 };
 
 ///For instance, SList_Iterator< Gtk::Widget >
@@ -176,18 +168,18 @@ public:
     return tmp;
   }
 
-  reference operator*()  const
+  reference operator*() const
   {
-    //g++ complains that this statement has no effect: g_assert(node_);
     return reinterpret_cast<T&>( node_ ? node_->data : glibmm_null_pointer );
   }
 
-  pointer operator -> () const { return &operator*(); }
+  pointer operator->() const { return &**this; }
 };
 
 
 // This iterator variation returns T_IFace (wrapped from T_Impl)
-//  For instance,  List_Cpp_Iterator<GtkWidget, Gtk::Widget> is a little like std::list<Gtk::Widget>::iterator
+// For instance,  List_Cpp_Iterator<GtkWidget, Gtk::Widget> is
+// a little like std::list<Gtk::Widget>::iterator
 template<class T_Impl, class T_IFace>
 class List_Cpp_Iterator : public List_Iterator_Base<T_IFace>
 {
@@ -227,21 +219,19 @@ public:
       //because we can not use a specific Glib::wrap(T_Impl) overload here,
       //because that would be "dependent", and g++ 3.4 does not allow that.
       //The specific Glib::wrap() overloads don't do anything special anyway.
-      GObject* cobj = static_cast<GObject*>( (*node_).data );
-      
-      #ifdef GLIBMM_CAN_USE_DYNAMIC_CAST_IN_UNUSED_TEMPLATE_WITHOUT_DEFINITION
-      return *(dynamic_cast<pointer>(Glib::wrap_auto(cobj, false /* take_copy */)));
-      #else
+      GObject* cobj = static_cast<GObject*>(node_->data);
+
+#ifdef GLIBMM_CAN_USE_DYNAMIC_CAST_IN_UNUSED_TEMPLATE_WITHOUT_DEFINITION
+      return *dynamic_cast<pointer>(Glib::wrap_auto(cobj, false));
+#else
       //We really do need to use dynamic_cast<>, so I expect problems if this code is used. murrayc.
-      return *(static_cast<pointer>(Glib::wrap_auto(cobj, false /* take_copy */)));
-      #endif
-      
+      return *static_cast<pointer>(Glib::wrap_auto(cobj, false));
+#endif
     }
-    
-    return *(pointer)glibmm_null_pointer;
+    return *static_cast<pointer>(0); // boom!
   }
 
-  pointer operator->() const { return &operator*(); }
+  pointer operator->() const { return &**this; }
 
   Self&  operator++()
   {
@@ -276,7 +266,6 @@ public:
     --*this;
     return tmp;
   }
-
 };
 
 template <class T_Base>
@@ -361,7 +350,7 @@ public:
   Self operator--(int) {Self src = *this; T_Base::operator--(); return src;}
 
   reference operator*() const { return T_Base::operator*(); }
-  pointer operator->()   const { return T_Base::operator->(); }
+  pointer operator->() const { return T_Base::operator->(); }
 };
 
 } // namespace Glib
@@ -369,4 +358,3 @@ public:
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 #endif /* _GLIBMM_CONTAINERS_H */
-
